@@ -1,6 +1,4 @@
-#!/usr/bin/env python
-
-from app import *
+from appkit.app import *
 import os
 import unittest
 
@@ -47,10 +45,11 @@ class AppKitUnitTest(unittest.TestCase):
 
     def test__run_server(self):
         (process, port) = self.app._run_server()
-        print process
+        print(process)
         self.assertIsInstance(process, multiprocessing.Process)
         self.assertIsInstance(port, int)
         process.terminate()
 
+
 if __name__ == '__main__':
     unittest.main()
